/* This file was generated by syncqt. */
#ifndef QT_QTWINEXTRAS_VERSION_H
#define QT_QTWINEXTRAS_VERSION_H

#define QTWINEXTRAS_VERSION_STR "5.9.5"

#define QTWINEXTRAS_VERSION 0x050905

#endif // QT_QTWINEXTRAS_VERSION_H
