/* This file was generated by syncqt. */
#ifndef QT_ACTIVEQT_VERSION_H
#define QT_ACTIVEQT_VERSION_H

#define ACTIVEQT_VERSION_STR "5.9.5"

#define ACTIVEQT_VERSION 0x050905

#endif // QT_ACTIVEQT_VERSION_H
